This module is designed to measure the performance (time) of a function.

When a function reference and parameters are passed, the function execution result and time are returned.

Results are stored in an internal list and can be saved as a file.